pub struct AuthDataV3 {
pub ecdsa_signature: [u8; 64],
pub ecdsa_attestation_key: [u8; 64],
pub qe_report: [u8; 384],
pub qe_report_signature: [u8; 64],
pub qe_auth_data: Data<u16>,
pub certification_data: CertificationData,
}Fields
ecdsa_signature: [u8; 64]ecdsa_attestation_key: [u8; 64]qe_report: [u8; 384]qe_report_signature: [u8; 64]qe_auth_data: Data<u16>certification_data: CertificationDataTrait Implementations
Sourceimpl Clone for AuthDataV3
impl Clone for AuthDataV3
Sourcefn clone(&self) -> AuthDataV3
fn clone(&self) -> AuthDataV3
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthDataV3
impl Debug for AuthDataV3
Sourceimpl Decode for AuthDataV3
impl Decode for AuthDataV3
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for AuthDataV3
impl<'de> Deserialize<'de> for AuthDataV3
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for AuthDataV3
impl Encode for AuthDataV3
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for AuthDataV3
impl Eq for AuthDataV3
Sourceimpl Hash for AuthDataV3
impl Hash for AuthDataV3
Sourceimpl Ord for AuthDataV3
impl Ord for AuthDataV3
Sourcefn cmp(&self, other: &AuthDataV3) -> Ordering
fn cmp(&self, other: &AuthDataV3) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for AuthDataV3
impl PartialEq for AuthDataV3
Sourceimpl PartialOrd for AuthDataV3
impl PartialOrd for AuthDataV3
Sourceimpl Serialize for AuthDataV3
impl Serialize for AuthDataV3
impl StructuralPartialEq for AuthDataV3