pub struct EnclaveReport {
pub cpu_svn: [u8; 16],
pub misc_select: u32,
pub reserved1: [u8; 28],
pub attributes: [u8; 16],
pub mr_enclave: [u8; 32],
pub reserved2: [u8; 32],
pub mr_signer: [u8; 32],
pub reserved3: [u8; 96],
pub isv_prod_id: u16,
pub isv_svn: u16,
pub reserved4: [u8; 60],
pub report_data: [u8; 64],
}Fields
cpu_svn: [u8; 16]misc_select: u32reserved1: [u8; 28]attributes: [u8; 16]mr_enclave: [u8; 32]reserved2: [u8; 32]mr_signer: [u8; 32]reserved3: [u8; 96]isv_prod_id: u16isv_svn: u16reserved4: [u8; 60]report_data: [u8; 64]Trait Implementations
Sourceimpl Clone for EnclaveReport
impl Clone for EnclaveReport
Sourcefn clone(&self) -> EnclaveReport
fn clone(&self) -> EnclaveReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EnclaveReport
Sourceimpl Debug for EnclaveReport
impl Debug for EnclaveReport
Sourceimpl Decode for EnclaveReport
impl Decode for EnclaveReport
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for EnclaveReport
impl<'de> Deserialize<'de> for EnclaveReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for EnclaveReport
impl Encode for EnclaveReport
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for EnclaveReport
impl Eq for EnclaveReport
Sourceimpl Hash for EnclaveReport
impl Hash for EnclaveReport
Sourceimpl Ord for EnclaveReport
impl Ord for EnclaveReport
Sourcefn cmp(&self, other: &EnclaveReport) -> Ordering
fn cmp(&self, other: &EnclaveReport) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for EnclaveReport
impl PartialEq for EnclaveReport
Sourceimpl PartialOrd for EnclaveReport
impl PartialOrd for EnclaveReport
Sourceimpl Serialize for EnclaveReport
impl Serialize for EnclaveReport
impl StructuralPartialEq for EnclaveReport