pub struct TDAttributes {
pub tud: u8,
pub sec: SECFlags,
pub other: OTHERFlags,
}Expand description
TD Attributes as defined in Intel TDX Module specification A.3.4
Fields
tud: u8TUD (TD Under Debug) flags (bits 7:0) If any of the bits in this group are set to 1, the TD is untrusted.
sec: SECFlagsSEC attributes that may impact the security of the TD (bits 31:8)
other: OTHERFlagsOTHER attributes that do not impact the security of the TD (bits 63:32)
Implementations