pub struct QuoteVerifier<C: Config = DefaultConfig> { /* private fields */ }Expand description
Quote verifier with configurable root certificate and crypto backend.
Provides both the backwards-compatible report API and the detailed claims API.
Implementations
Sourceimpl<C: Config> QuoteVerifier<C>
impl<C: Config> QuoteVerifier<C>
Sourcepub fn new_with_config(root_ca_der: Vec<u8>) -> Self
pub fn new_with_config(root_ca_der: Vec<u8>) -> Self
Create a verifier for C with a custom root certificate.
Sourcepub fn with_config<D: Config>(self) -> QuoteVerifier<D>
pub fn with_config<D: Config>(self) -> QuoteVerifier<D>
Select a different compile-time verification backend.
pub fn allow_service_td(self, allow: bool) -> Self
pub fn allow_debug(self, allow: bool) -> Self
Sourcepub fn verify_with_policy<P: Policy + ?Sized>(
&self,
raw_quote: &[u8],
collateral: impl Into<QuoteCollateralV3>,
now_secs: u64,
policy: &P,
) -> Result<QuoteClaims>
pub fn verify_with_policy<P: Policy + ?Sized>( &self, raw_quote: &[u8], collateral: impl Into<QuoteCollateralV3>, now_secs: u64, policy: &P, ) -> Result<QuoteClaims>
Verify a quote, apply a policy, and return detailed serializable claims.
Sourcepub fn verify(
&self,
raw_quote: &[u8],
collateral: &QuoteCollateralV3,
now_secs: u64,
) -> Result<VerifiedReport>
pub fn verify( &self, raw_quote: &[u8], collateral: &QuoteCollateralV3, now_secs: u64, ) -> Result<VerifiedReport>
Verify with the one-shot API using this verifier’s Config.